#
# spec file for package python-pytest-doc
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-pytest-doc
Version:        2.8.7
Release:        2.2
Summary:        Simple powerful testing with Python
License:        MIT
Group:          Development/Languages/Python
Url:            http://pytest.org
Source:         http://pypi.python.org/packages/source/p/pytest/pytest-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-Sphinx
BuildRequires:  python-py >= 1.4.22
%if 0%{?suse_version} && 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description
pytest helps you write better programs. It is a a mature full-featured,
cross-project Python testing tool. It provides:

* auto-discovery of test modules and functions,
* detailed info on failing assert statements (no need to remember 
  self.assert* names),
* modular fixtures for managing small or parametrized long-lived test resources.
* multi-paradigm support: you can use py.test to run test suites based on 
  unittest (or trial), nose,
* single-source compatibility to Python2.4 all the way up to Python3.3, 
  PyPy-1.9 and Jython-2.5.1, and
* many external plugins.

This package contains the documentation for pytest


%prep
%setup -q -n pytest-%{version}

%build
python setup.py build_sphinx
rm doc/build/html/.buildinfo

%install
# Only building documentation

%files
%defattr(-,root,root,-)
%doc LICENSE CHANGELOG
%doc doc/build/html

%changelog
* Mon Feb  1 2016 toddrme2178@gmail.com
- update to version 2.8.7:
  * fix #1338: use predictable object resolution for monkeypatch
- changes from version 2.8.6:
  * fix #1259: allow for double nodeids in junitxml, this was a
    regression failing plugins combinations like pytest-pep8 +
    pytest-flakes
  * Workaround for exception that occurs in pyreadline when using
  - -pdb with standard I/O capture enabled. Thanks Erik M. Bray for
    the PR.
  * fix #900: Better error message in case the target of a monkeypatch
    call raises an ImportError.
  * fix #1292: monkeypatch calls (setattr, setenv, etc.) are now
    O(1). Thanks David R. MacIver for the report and Bruno Oliveira
    for the PR.
  * fix #1223: captured stdout and stderr are now properly displayed
    before entering pdb when --pdb is used instead of being thrown
    away. Thanks Cal Leeming for the PR.
  * fix #1305: pytest warnings emitted during pytest_terminal_summary
    are now properly displayed. Thanks Ionel Maries Cristian for the
    report and Bruno Oliveira for the PR.
  * fix #628: fixed internal UnicodeDecodeError when doctests contain
    unicode. Thanks Jason R. Coombs for the report and Bruno Oliveira
    for the PR.
  * fix #1334: Add captured stdout to jUnit XML report on setup
    error. Thanks Georgy Dyuldin for the PR.
- Update to version 2.8.5
  * fix #1243: fixed issue where class attributes injected during
    collection could break pytest.
    fix #1074: precompute junitxml chunks instead of storing the
    whole tree in objects
    fix #1238: fix pytest.deprecated_call() receiving multiple
    arguments (Regression introduced in 2.8.4).
- update to version 2.8.4:
  * fix #1190: deprecated_call() now works when the deprecated
    function has been already called by another test in the same
    module. Thanks Mikhail Chernykh for the report and Bruno Oliveira
    for the PR.
  * fix #1198: --pastebin option now works on Python 3. Thanks Mehdy
    Khoshnoody for the PR.
  * fix #1219: --pastebin now works correctly when captured output
    contains non-ascii characters. Thanks Bruno Oliveira for the PR.
  * fix #1204: another error when collecting with a nasty
    __getattr__(). Thanks Florian Bruhin for the PR.
  * fix the summary printed when no tests did run. Thanks Florian
    Bruhin for the PR.
  * a number of documentation modernizations wrt good
    practices. Thanks Bruno Oliveira for the PR.
- update to version 2.8.3:
  * fix #1169: add __name__ attribute to testcases in TestCaseFunction
    to support the @unittest.skip decorator on functions and methods.
    Thanks Lee Kamentsky for the PR.
  * fix #1035: collecting tests if test module level obj has
    __getattr__().  Thanks Suor for the report and Bruno Oliveira /
    Tom Viner for the PR.
  * fix #331: don't collect tests if their failure cannot be reported
    correctly e.g. they are a callable instance of a class.
  * fix #1133: fixed internal error when filtering tracebacks where
    one entry belongs to a file which is no longer available.  Thanks
    Bruno Oliveira for the PR.
  * enhancement made to highlight in red the name of the failing tests
    so they stand out in the output.  Thanks Gabriel Reis for the PR.
  * add more talks to the documentation
  * extend documentation on the --ignore cli option
  * use pytest-runner for setuptools integration
  * minor fixes for interaction with OS X El Capitan system integrity
    protection (thanks Florian)
* Sun May 24 2015 toddrme2178@gmail.com
- Split documentation into separate package to avoid build loop
